Command Line Interface
======================

Bitwuzla provides a command line interface that supports parsing of SMT-LIBv2
:cite:`smtlib2` and non-sequential BTOR2 :cite:`btor2` input files (i.e. no
model-checking features supported).


The command line usage of Bitwuzla is as follows:

.. literalincludegen:: cli_usage.txt
   :language: none
